Documentation
¶
Index ¶
- type AttributesOptionsSliceProvider
- type AttributesProvider
- type CodeBlockRenderer
- type CodeblockContext
- type ElementPositionResolver
- type GetRendererFunc
- type HeadingContext
- type HeadingRenderer
- type ImageLinkContext
- type IsDefaultCodeBlockRendererProvider
- type LinkContext
- type LinkRenderer
- type RendererType
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AttributesOptionsSliceProvider ¶
type AttributesOptionsSliceProvider interface {
AttributesSlice() []attributes.Attribute
OptionsSlice() []attributes.Attribute
}
type AttributesProvider ¶
type CodeBlockRenderer ¶
type CodeBlockRenderer interface {
RenderCodeblock(cctx context.Context, w hugio.FlexiWriter, ctx CodeblockContext) error
}
type CodeblockContext ¶
type CodeblockContext interface {
AttributesProvider
text.Positioner
// Chroma highlighting processing options. This will only be filled if Type is a known Chroma Lexer.
Options() map[string]any
// The type of code block. This will be the programming language, e.g. bash, when doing code highlighting.
Type() string
// The text between the code fences.
Inner() string
// Zero-based ordinal for all code blocks in the current document.
Ordinal() int
// The owning Page.
Page() any
}
CodeblockContext is the context passed to a code block render hook.
type ElementPositionResolver ¶
ElementPositionResolver provides a way to resolve the start Position of a markdown element in the original source document. This may be both slow and approximate, so should only be used for error logging.
type GetRendererFunc ¶
type GetRendererFunc func(t RendererType, id any) any
type HeadingContext ¶
type HeadingContext interface {
// Page is the page containing the heading.
Page() any
// Level is the level of the header (i.e. 1 for top-level, 2 for sub-level, etc.).
Level() int
// Anchor is the HTML id assigned to the heading.
Anchor() string
// Text is the rendered (HTML) heading text, excluding the heading marker.
Text() hstring.RenderedString
// PlainText is the unrendered version of Text.
PlainText() string
// Attributes (e.g. CSS classes)
AttributesProvider
}
HeadingContext contains accessors to all attributes that a HeadingRenderer can use to render a heading.
type HeadingRenderer ¶
type HeadingRenderer interface {
// RenderHeading writes the rendered content to w using the data in w.
RenderHeading(cctx context.Context, w io.Writer, ctx HeadingContext) error
}
HeadingRenderer describes a uniquely identifiable rendering hook.
type ImageLinkContext ¶
type ImageLinkContext interface {
LinkContext
// Returns true if this is a standalone image and the config option
// markup.goldmark.parser.wrapStandAloneImageWithinParagraph is disabled.
IsBlock() bool
// Zero-based ordinal for all the images in the current document.
Ordinal() int
}
ImageLinkContext is the context passed to a image link render hook.
type IsDefaultCodeBlockRendererProvider ¶
type IsDefaultCodeBlockRendererProvider interface {
IsDefaultCodeBlockRenderer() bool
}
type LinkContext ¶
type LinkContext interface {
// The Page being rendered.
Page() any
// The link URL.
Destination() string
// The link title attribute.
Title() string
// The rendered (HTML) text.
Text() hstring.RenderedString
// The plain variant of Text.
PlainText() string
}
LinkContext is the context passed to a link render hook.
type LinkRenderer ¶
type RendererType ¶
type RendererType int
const ( LinkRendererType RendererType = iota + 1 ImageRendererType HeadingRendererType CodeBlockRendererType )
Click to show internal directories.
Click to hide internal directories.